@@ -662,7 +662,7 @@ sub latex {
 \newcommand*{\Slash}{\slash\hspace{0pt}}
 
 % global style
-\pagestyle{plain}
+\pagestyle{[% IF safe_options.headings %]headings[% ELSE %]plain[% END %]}
 \addtokomafont{disposition}{\rmfamily}
 \addtokomafont{descriptionlabel}{\rmfamily}
 % forbid widows/orphans
@@ -684,29 +684,39 @@ sub latex {
 \hyphenation{ [% doc.hyphenation %] }
 [% END %]
 
-[% IF safe_options.cover %]
-  \thispagestyle{empty}
-  \strut\bigskip
-  \begin{center}
-    [% IF doc.header_defined.author %]
-    {\Large\textbf{[% doc.header_as_latex.author %]}\\[\baselineskip]}
-    [% END %]
-    {\LARGE\textbf{[% doc.header_as_latex.title %]\\[\baselineskip]}}
-    [% IF doc.header_defined.subtitle %]
-      {\Large\textbf{[% doc.header_as_latex.subtitle %]}\\[\baselineskip]}
-    [% END %]
-    \vfill
-    \includegraphics[width=[% safe_options.coverwidth %]\textwidth]{[% safe_options.cover %]}
-    \vfill
-    [% IF doc.header_defined.date %]
-    {\large [% doc.header_as_latex.date %]}
-    [% END %]
-    \strut
-  \end{center}
-[% ELSE %]
-\maketitle
-[% END %]
 [% UNLESS safe_options.nocoverpage %]
+  \begin{titlepage}
+[% END %]
+  \strut\vskip 2em
+  \begin{center}
+  {\usekomafont{title}{\huge [% doc.header_as_latex.title %]\par}}%
+  \vskip 1em
+  [% IF doc.header_defined.subtitle %]
+  {\usekomafont{subtitle}{[% doc.header_as_latex.subtitle %]\par}}%
+  [% END %]
+  \vskip 2em
+  [% IF doc.header_defined.author %]
+  {\usekomafont{author}{[% doc.header_as_latex.author %]\par}}%
+  [% END %]
+  \vskip 1.5em
+[% UNLESS safe_options.nocoverpage %]
+   [% IF safe_options.cover %]
+      \vskip 3em
+      \includegraphics[width=[% safe_options.coverwidth %]\textwidth]{[% safe_options.cover %]}
+   [% END %]
+   \vfill
+[% END %]
+  [% IF doc.header_defined.date %]
+  {\usekomafont{date}{[% doc.header_as_latex.date %]\par}}%
+  [% ELSE %]
+    \strut\par
+  [% END %]
+  \end{center}
+[% IF safe_options.nocoverpage %]
+  \vskip 3em
+  \par
+[% ELSE %]
+  \end{titlepage}
 \cleardoublepage
 [% END %]
 
@@ -877,20 +887,20 @@ sub bare_latex {
 \vspace{0.1\textheight}
 
 \begin{center}
-\huge{\textbf{[% doc.header_as_latex.title %]}\par}
-\bigskip
-[% IF doc.header_defined.subtitle %]
-\LARGE{\textbf{[% doc.header_as_latex.subtitle %]}\par}
-\bigskip
-[% END %]
-[% IF doc.header_defined.author %]
-\Large{[% doc.header_as_latex.author %]\par}
-\bigskip
-[% END %]
-[% IF doc.header_defined.date %]
-\large{[% doc.header_as_latex.date %]}
-[% END %]
-
+  \strut\vskip 2em
+  {\usekomafont{title}{\huge [% doc.header_as_latex.title %]\par}}%
+  \vskip 1em
+  [% IF doc.header_defined.subtitle %]
+  {\usekomafont{subtitle}{[% doc.header_as_latex.subtitle %]\par}}%
+  [% END %]
+  \vskip 2em
+  [% IF doc.header_defined.author %]
+  {\usekomafont{author}{[% doc.header_as_latex.author %]\par}}%
+  [% END %]
+  \vskip 1.5em
+  [% IF doc.header_defined.date %]
+  {\usekomafont{date}{[% doc.header_as_latex.date %]\par}}%
+  [% END %]
 \end{center}
 
 \vfill
